
/* Copyright (C) MOXA Inc. All rights reserved.

   This is free software distributed under the terms of the
   GNU Public License.  See the file COPYING-GPL for details.

   tcan.c
   This is a test program to test Moxa CAN bus card device driver on Linux.
   You need to connect the CAN1 to CAN2 for loopback testing.

   History:
   Date		Author			Comment
   01-17-2008	Victor Yu.		Create it.
*/

#include	<stdio.h>
#include	<stdlib.h>
#include	<fcntl.h>
#include	<string.h>
#include	"moxacan_ioctl.h"

#define PORT1_NAME	"/dev/can0"
#define PORT2_NAME	"/dev/can1"

int	main(int argc, char *argv[])
{
	int		fd1, fd2;
	int		i, baudrate;
	user_frame_t	txframe, rxframe;

	// open CAN device node to let AP to control it
	fd1 = open(PORT1_NAME, O_RDWR);
	if ( fd1 < 0 ) {
		printf("Open %s fail !\n", PORT1_NAME);
		return -1;
	}
	fd2 = open(PORT2_NAME, O_RDWR);
	if ( fd2 < 0 ) {
		printf("Open %s fail !\n", PORT2_NAME);
		close(fd1);
		return -1;
	}

	// set baud rate
	baudrate = 100000;	// 100K
	ioctl(fd1, MOXACAN_IOCTL_SET_BAUD_RATE, &baudrate);
	ioctl(fd2, MOXACAN_IOCTL_SET_BAUD_RATE, &baudrate);

	// with extend ID address testing
	// first port 1 send and port 2 receive
	// clear frame buffer
	memset(&txframe, 0, sizeof(txframe));
	memset(&rxframe, 0, sizeof(rxframe));

	txframe.id = 12;
	txframe.data_length = MAX_CAN_DATA_LENGTH;
	txframe.info |= USER_EXTEND_ID;
	for ( i=0; i<MAX_CAN_DATA_LENGTH; i++ )
		txframe.data.array[i] = 0x30+i;

	i = write(fd1, &txframe, sizeof(txframe));
	printf("Write port1 data return = %d\n", i);
	printf("Write data contexts are following :\n");
	for ( i=0; i<MAX_CAN_DATA_LENGTH; i++ )
		printf("%c", txframe.data.array[i]);
	printf("\n");
	sleep(1);
	i = read(fd2, &rxframe, sizeof(rxframe));
	printf("Read port2 data return = %d\n", i);
	printf("Receive frame id = %d, length = %d\n", rxframe.id, rxframe.data_length);
	printf("Receive data contexts are following :\n");
	for ( i=0; i<MAX_CAN_DATA_LENGTH; i++ )
		printf("%c", rxframe.data.array[i]);
	printf("\n");

	close(fd1);
	close(fd2);

	return 0;
}
