/*
  Copyright (C) MOXA Inc. All rights reserved.
  This software is distributed under the terms of the
  MOXA License.  See the file COPYING-MOXA for details.
*/

/*******************************************************************************
File Name : logger.c

Description : 
	Read data from 8 serial ports and print on the screen what received
	
Usage : 
	1.Compile this file and execute on target platform.
	
History : 
	Version		Author		Date		Comment
	1.0		AceLan		01-05-2006	Using library
*******************************************************************************/
#include <stdio.h>
#include <sys/timeb.h>
#include "serial.h"

#define MAXPORT		8
#define BAUDRATE	9600
#define LOG_FILE	"serial.log"

#define GETCLOCKSECOND( s, m) {				\
		struct timeb tv;			\
		ftime( &tv);				\
		s= tv.time;				\
		m= tv.millitm;				\
	}

int main( void)
{
	char tmp[ 80];
	int i, maxfd= -1;
	int second, ms;

	int tmpfd, fds[ 8];
	fd_set readfds;

	FILE* fd;
	fd= fopen( LOG_FILE, "wt");
	
	for( i= 0; i< MAXPORT; i++)
	{
		SerialOpen( i);
		SerialSetMode( i, RS232_MODE);
		SerialSetSpeed( i, BAUDRATE);

		fds[ i]= FindFD( i);
		if( fds[ i] > maxfd)
			maxfd= fds[ i];
	}
	
	while( 1)
	{
		for( i= 0; i< MAXPORT; i++)
			FD_SET( fds[ i], &readfds);
		tmpfd= select( maxfd+ 1, &readfds, NULL, NULL, NULL);
		for( i= 0; i< MAXPORT; i++)
			if( FD_ISSET( fds[ i], &readfds))
				break;
		if( i == MAXPORT)
			continue;

		SerialBlockRead( i, tmp, 80);

		GETCLOCKSECOND( second, ms);
		fprintf( fd, "PORT%d : %d.%d - %s\n", i+ 1, second, ms, tmp);
		printf( "PORT%d : %d.%d - %s\n", i+ 1, second, ms, tmp);
		fflush( fd);
	}
	
	return 0;
}

